"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Editor = void 0;
/** @jsx jsx */
/* eslint react/jsx-key: 0 */
const react_1 = require("react");
const theme_ui_1 = require("theme-ui");
const is_hotkey_1 = __importDefault(require("is-hotkey"));
const slate_react_1 = require("slate-react");
const slate_1 = require("slate");
const slate_history_1 = require("slate-history");
const editor_helpers_1 = require("./editor-helpers");
const components_1 = require("./components");
const style_1 = require("./style");
const serializeHTML_1 = require("./serializeHTML");
const deserializeHTML_1 = require("./deserializeHTML");
const HOTKEYS = {
    'mod+b': 'bold',
    'mod+i': 'italic',
    'mod+u': 'underline',
    'mod+`': 'code',
};
exports.Editor = ({ value = '<p><span> </span></p>', toolbar = true, placeholder, spellCheck, autoFocus, onChange, }) => {
    const renderElement = react_1.useCallback((props) => theme_ui_1.jsx(components_1.EditorElement, Object.assign({}, props)), []);
    const renderLeaf = react_1.useCallback((props) => theme_ui_1.jsx(components_1.EditorLeaf, Object.assign({}, props)), []);
    const editor = react_1.useMemo(() => slate_history_1.withHistory(slate_react_1.withReact(slate_1.createEditor())), []);
    const document = new DOMParser().parseFromString(value ? value : '<p><span> </span></p>', 'text/html');
    const deserealizedText = deserializeHTML_1.deserializeHTML(document.body);
    const [editorText, setEditorText] = react_1.useState(deserealizedText);
    return (theme_ui_1.jsx(theme_ui_1.Container, { sx: style_1.style },
        theme_ui_1.jsx(theme_ui_1.Container, { className: "editor-container" },
            theme_ui_1.jsx(slate_react_1.Slate, { editor: editor, value: editorText, onChange: (newValue) => {
                    if (onChange) {
                        const htmlText = serializeHTML_1.serializeHTML({ children: newValue });
                        onChange(htmlText);
                    }
                    setEditorText(newValue);
                } },
                toolbar && (theme_ui_1.jsx(components_1.EditorToolbar, null,
                    theme_ui_1.jsx(components_1.EditorMarkButton, { format: "bold", icon: "format_bold" }),
                    theme_ui_1.jsx(components_1.EditorMarkButton, { format: "italic", icon: "format_italic" }),
                    theme_ui_1.jsx(components_1.EditorMarkButton, { format: "underline", icon: "format_underlined" }),
                    theme_ui_1.jsx(components_1.EditorMarkButton, { format: "code", icon: "code" }),
                    theme_ui_1.jsx(components_1.EditorBlockButton, { format: "heading-one", icon: "looks_one" }),
                    theme_ui_1.jsx(components_1.EditorBlockButton, { format: "heading-two", icon: "looks_two" }),
                    theme_ui_1.jsx(components_1.EditorBlockButton, { format: "block-quote", icon: "format_quote" }),
                    theme_ui_1.jsx(components_1.EditorBlockButton, { format: "numbered-list", icon: "format_list_numbered" }),
                    theme_ui_1.jsx(components_1.EditorBlockButton, { format: "bulleted-list", icon: "format_list_bulleted" }))),
                theme_ui_1.jsx(slate_react_1.Editable, { renderElement: renderElement, renderLeaf: renderLeaf, placeholder: placeholder, spellCheck: spellCheck, autoFocus: autoFocus, onKeyDown: (event) => {
                        for (const hotkey in HOTKEYS) {
                            if (is_hotkey_1.default(hotkey, event)) {
                                event.preventDefault();
                                const mark = HOTKEYS[hotkey];
                                editor_helpers_1.toggleMark(editor, mark);
                            }
                        }
                    } })))));
};
//# sourceMappingURL=Editor.js.map