"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toggleMark = exports.toggleBlock = exports.isMarkActive = exports.isBlockActive = void 0;
const slate_1 = require("slate");
const LIST_TYPES = ['numbered-list', 'bulleted-list'];
exports.isBlockActive = (editor, format) => {
    const [match] = slate_1.Editor.nodes(editor, {
        match: (n) => n.type === format,
    });
    return !!match;
};
exports.isMarkActive = (editor, format) => {
    const marks = slate_1.Editor.marks(editor);
    return marks ? marks[format] === true : false;
};
exports.toggleBlock = (editor, format) => {
    const isActive = exports.isBlockActive(editor, format);
    const isList = LIST_TYPES.includes(format);
    slate_1.Transforms.unwrapNodes(editor, {
        match: (n) => LIST_TYPES.includes(n.type),
        split: true,
    });
    slate_1.Transforms.setNodes(editor, {
        type: isActive ? 'paragraph' : isList ? 'list-item' : format,
    });
    if (!isActive && isList) {
        const block = { type: format, children: [] };
        slate_1.Transforms.wrapNodes(editor, block);
    }
};
exports.toggleMark = (editor, format) => {
    const isActive = exports.isMarkActive(editor, format);
    if (isActive) {
        slate_1.Editor.removeMark(editor, format);
    }
    else {
        slate_1.Editor.addMark(editor, format, true);
    }
};
//# sourceMappingURL=editor-helpers.js.map