"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileUpload = void 0;
/** @jsx jsx */
const react_1 = require("react");
const theme_ui_1 = require("theme-ui");
const components_1 = require("./components");
const defaultProps = {
    value: [],
    accept: 'image/*',
    multiple: false,
};
exports.FileUpload = (props) => {
    const { value, id, accept, multiple, buttonComponent, validate, upload, remove, } = props;
    const [loading, setLoading] = react_1.useState(false);
    const [errors, setErrors] = react_1.useState([]);
    const inputRef = react_1.useRef(null);
    const onButtonClick = () => inputRef.current && inputRef.current.click();
    const onInputChange = (event) => __awaiter(void 0, void 0, void 0, function* () {
        const { files: filesToUpload } = event.target;
        if (!(filesToUpload === null || filesToUpload === void 0 ? void 0 : filesToUpload.length)) {
            return;
        }
        if (validate) {
            const validationErrors = Array.from(filesToUpload).reduce((acc, file) => {
                const err = validate(file);
                if (err) {
                    acc.push(err);
                }
                return acc;
            }, []);
            if (validationErrors.length) {
                setErrors(validationErrors);
                return;
            }
        }
        setLoading(true);
        try {
            yield upload(filesToUpload);
        }
        catch (err) {
            setErrors([err.message]);
        }
        setLoading(false);
    });
    return (theme_ui_1.jsx("div", { sx: { width: '100%' } },
        theme_ui_1.jsx("label", { htmlFor: id },
            buttonComponent || (theme_ui_1.jsx(components_1.FileUploadButton, { loading: loading, onClick: onButtonClick })),
            theme_ui_1.jsx(components_1.FileUploadInput, { id: id, inputRef: inputRef, onChange: onInputChange, accept: accept, multiple: multiple })),
        errors && errors.length > 0 && (theme_ui_1.jsx(theme_ui_1.Text, { sx: { color: 'error', mt: 2 } }, errors.join(' '))),
        value && value.length > 0 && (theme_ui_1.jsx(theme_ui_1.Flex, null, value.map((file, i) => (theme_ui_1.jsx(components_1.FileUploadPreview, { key: i, file: file, onRemove: remove })))))));
};
exports.FileUpload.defaultProps = defaultProps;
exports.FileUpload.displayName = 'FileUpload';
//# sourceMappingURL=FileUpload.js.map