/** @jsx jsx */
/* eslint react/jsx-key: 0 */
import { useCallback, useMemo, useState } from 'react';
import { Container, jsx } from 'theme-ui';
import isHotkey from 'is-hotkey';
import { Editable, withReact, Slate } from 'slate-react';
import { createEditor } from 'slate';
import { withHistory } from 'slate-history';
import { toggleMark } from './editor-helpers';
import { EditorBlockButton, EditorElement, EditorLeaf, EditorMarkButton, EditorToolbar, } from './components';
import { style } from './style';
import { serializeHTML } from './serializeHTML';
import { deserializeHTML } from './deserializeHTML';
const HOTKEYS = {
    'mod+b': 'bold',
    'mod+i': 'italic',
    'mod+u': 'underline',
    'mod+`': 'code',
};
export const Editor = ({ value = '<p><span> </span></p>', toolbar = true, placeholder, spellCheck, autoFocus, onChange, }) => {
    const renderElement = useCallback((props) => jsx(EditorElement, Object.assign({}, props)), []);
    const renderLeaf = useCallback((props) => jsx(EditorLeaf, Object.assign({}, props)), []);
    const editor = useMemo(() => withHistory(withReact(createEditor())), []);
    const document = new DOMParser().parseFromString(value ? value : '<p><span> </span></p>', 'text/html');
    const deserealizedText = deserializeHTML(document.body);
    const [editorText, setEditorText] = useState(deserealizedText);
    return (jsx(Container, { sx: style },
        jsx(Container, { className: "editor-container" },
            jsx(Slate, { editor: editor, value: editorText, onChange: (newValue) => {
                    if (onChange) {
                        const htmlText = serializeHTML({ children: newValue });
                        onChange(htmlText);
                    }
                    setEditorText(newValue);
                } },
                toolbar && (jsx(EditorToolbar, null,
                    jsx(EditorMarkButton, { format: "bold", icon: "format_bold" }),
                    jsx(EditorMarkButton, { format: "italic", icon: "format_italic" }),
                    jsx(EditorMarkButton, { format: "underline", icon: "format_underlined" }),
                    jsx(EditorMarkButton, { format: "code", icon: "code" }),
                    jsx(EditorBlockButton, { format: "heading-one", icon: "looks_one" }),
                    jsx(EditorBlockButton, { format: "heading-two", icon: "looks_two" }),
                    jsx(EditorBlockButton, { format: "block-quote", icon: "format_quote" }),
                    jsx(EditorBlockButton, { format: "numbered-list", icon: "format_list_numbered" }),
                    jsx(EditorBlockButton, { format: "bulleted-list", icon: "format_list_bulleted" }))),
                jsx(Editable, { renderElement: renderElement, renderLeaf: renderLeaf, placeholder: placeholder, spellCheck: spellCheck, autoFocus: autoFocus, onKeyDown: (event) => {
                        for (const hotkey in HOTKEYS) {
                            if (isHotkey(hotkey, event)) {
                                event.preventDefault();
                                const mark = HOTKEYS[hotkey];
                                toggleMark(editor, mark);
                            }
                        }
                    } })))));
};
//# sourceMappingURL=Editor.js.map