var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
/** @jsx jsx */
import { useRef, useState } from 'react';
import { jsx, Flex, Text } from 'theme-ui';
import { FileUploadButton, FileUploadInput, FileUploadPreview, } from './components';
const defaultProps = {
    value: [],
    accept: 'image/*',
    multiple: false,
};
export const FileUpload = (props) => {
    const { value, id, accept, multiple, buttonComponent, validate, upload, remove, } = props;
    const [loading, setLoading] = useState(false);
    const [errors, setErrors] = useState([]);
    const inputRef = useRef(null);
    const onButtonClick = () => inputRef.current && inputRef.current.click();
    const onInputChange = (event) => __awaiter(void 0, void 0, void 0, function* () {
        const { files: filesToUpload } = event.target;
        if (!(filesToUpload === null || filesToUpload === void 0 ? void 0 : filesToUpload.length)) {
            return;
        }
        if (validate) {
            const validationErrors = Array.from(filesToUpload).reduce((acc, file) => {
                const err = validate(file);
                if (err) {
                    acc.push(err);
                }
                return acc;
            }, []);
            if (validationErrors.length) {
                setErrors(validationErrors);
                return;
            }
        }
        setLoading(true);
        try {
            yield upload(filesToUpload);
        }
        catch (err) {
            setErrors([err.message]);
        }
        setLoading(false);
    });
    return (jsx("div", { sx: { width: '100%' } },
        jsx("label", { htmlFor: id },
            buttonComponent || (jsx(FileUploadButton, { loading: loading, onClick: onButtonClick })),
            jsx(FileUploadInput, { id: id, inputRef: inputRef, onChange: onInputChange, accept: accept, multiple: multiple })),
        errors && errors.length > 0 && (jsx(Text, { sx: { color: 'error', mt: 2 } }, errors.join(' '))),
        value && value.length > 0 && (jsx(Flex, null, value.map((file, i) => (jsx(FileUploadPreview, { key: i, file: file, onRemove: remove })))))));
};
FileUpload.defaultProps = defaultProps;
FileUpload.displayName = 'FileUpload';
//# sourceMappingURL=FileUpload.js.map