var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
/** @jsx jsx */
/* eslint react/jsx-key: 0 */
import React, { useEffect, useState } from 'react';
import { Container, Flex, Text, jsx, Input, Label } from 'theme-ui';
import { TextPosition } from './prefilled-input-props';
export const PrefilledInput = React.forwardRef((_a, ref) => {
    var { value = '', prefilledText, label, name, prefilledTextPosition = TextPosition.RIGHT, placeholder } = _a, props = __rest(_a, ["value", "prefilledText", "label", "name", "prefilledTextPosition", "placeholder"]);
    const spanRef = React.createRef();
    const [inputRef, setInputRef] = useState(null);
    const [focused, setFocus] = useState(false);
    const [inputWidth, setInputWidth] = useState();
    useEffect(() => {
        if (!spanRef.current) {
            setInputWidth('auto');
            return;
        }
        if (placeholder && placeholder.length !== 0) {
            spanRef.current.textContent = placeholder;
        }
        else if (value && value.length !== 0) {
            spanRef.current.textContent = value;
        }
        setInputWidth(spanRef.current.offsetWidth + 'px');
    }, []);
    const onChange = (event) => {
        // the hidden span takes the value of the input;
        if (spanRef.current) {
            let inputWidth = 'auto';
            if (event.target.value.length !== 0) {
                spanRef.current.textContent = event.target.value;
                inputWidth = spanRef.current.offsetWidth + 'px';
            }
            else if (placeholder && placeholder.length !== 0) {
                spanRef.current.textContent = placeholder;
                inputWidth = spanRef.current.offsetWidth + 'px';
            }
            setInputWidth(inputWidth); // apply width of the span to the input
        }
        //setInputText(event.target.value);
        if (props.onChange) {
            props.onChange(event);
        }
    };
    const onFocus = (event) => {
        setFocus(true);
        if (props.onFocus) {
            props.onFocus(event);
        }
    };
    const onBlur = (event) => {
        setFocus(false);
        if (props.onFocus) {
            props.onFocus(event);
        }
    };
    return (jsx(Flex, { sx: { alignItems: 'center' } },
        name && label && (jsx(Label, { htmlFor: name, sx: { width: 'auto', minWidth: '8.75rem', flexGrow: 1 } }, label)),
        jsx(Container, { sx: {
                cursor: 'pointer',
                borderRadius: '23px',
                border: '1px solid',
                borderColor: focused || value.length !== 0 ? 'gray0' : 'gray1',
                px: 3,
                py: '0.812rem',
                flexGrow: 3,
            }, onClick: () => inputRef === null || inputRef === void 0 ? void 0 : inputRef.focus() },
            jsx(Flex, { sx: {
                    flexDirection: prefilledTextPosition === TextPosition.RIGHT
                        ? 'row-reverse'
                        : 'row',
                } },
                jsx(Text, { sx: {
                        m: '0 5px 0 5px',
                        flex: prefilledTextPosition === TextPosition.RIGHT
                            ? '1 0 auto'
                            : '0 1 auto',
                    } }, prefilledText),
                jsx(Input, { sx: {
                        width: inputWidth,
                        border: 'none',
                        borderColor: 'inherit',
                        boxShadow: 'none',
                        padding: 0,
                        borderRadius: 0,
                    }, ref: (node) => {
                        setInputRef(node);
                        if (typeof ref === 'function') {
                            ref(node);
                        }
                        else if (ref) {
                            ref.current = node;
                        }
                    }, type: "text", placeholder: placeholder, value: value, name: name, onChange: onChange, onFocus: onFocus, onBlur: onBlur }),
                jsx("span", { ref: spanRef, sx: {
                        position: 'absolute',
                        left: '-9999px',
                        top: '-9999px',
                    } }, value)))));
});
//# sourceMappingURL=PrefilledInput.js.map